import React from "react";
import { Field } from "redux-form";

export default ({ label, inputType, touch, valid, config }) => {
	let component = null;
	switch (inputType) {
		case "textarea": {
			component = (
				<textarea className={touch && valid ? "input-box__error" : "input-box__input"} {...config} />
			);
			break;
		}
		case "select": {
			component = (
				<select className={touch && valid ? "input-box__error" : "input-box__input"} {...config}>
					{config.option.map(el => (
						<option key={el.value} value={el.value}>
							{el.name}
						</option>
					))}
				</select>
			);
			break;
		}
		default:
			return renderField();
	}

	return (
		<div className="input-box">
			<label className="input-box__label">{label}</label>
			{component}
		</div>
	);
};

export const renderField = ({ input, label, type = "text", meta: { touched, error } }) => {
	return (
		<div>
			<label>{label}</label>
			<div>
				<input {...input} placeholder={label} type={type} />
				{touched && error && <span>{error}</span>}
			</div>
		</div>
	);
};

export const renderCheckbox = ({ input, label, meta: { touched, error } }) => {
	return (
		<div>
			<label>{label}</label>
			<div>
				<input {...input} placeholder={label} type="checkbox" />
				{touched && error && <span>{error}</span>}
			</div>
		</div>
	);
};

export const renderSelect = ({ input, children, label, meta: { touched, error } }) => {
	return (
		<div>
			<label>{label}</label>
			<div>
				<select {...input}>{children}</select>
				{touched && error && <span>{error}</span>}
			</div>
		</div>
	);
};

export const renderArr = ({ fields, meta: { error, submitFailed } }) => (
	<ul>
		<li>
			<button type="button" onClick={() => fields.push({})}>
				Add Member
			</button>
			{submitFailed && error && <span>{error}</span>}
		</li>
		{fields.map((elem, index) => (
			<li key={index}>
				<button type="button" title="Remove Member" onClick={() => fields.remove(index)}>
					Remove
				</button>
				<Field name={`${elem}.item`} component={renderField} label="Item" />
			</li>
		))}
	</ul>
);
