import { useState } from "react";

import checkObject from "../../utils/checkObject";

const useForm = initialValues => {
	const [newObject, setNewObject] = useState(initialValues);

	const validate = (rules, value, otherField) => {
		let isValid = true;
		if (rules.required) {
			isValid = value.trim() !== "" && isValid;
		}

		if (rules.sameWithPassword) {
			isValid = value.trim() !== "" && otherField.password.value.trim() === value.trim() && isValid;
		}

		return isValid;
	};

	const setNew = ({ name, value }) => {
		setNewObject(newObject => {
			const valid = validate(newObject[name].validation, value, newObject);

			const otherValid = Object.keys(newObject)
				.reduce(
					(prev, el) =>
						checkObject(newObject[el]) && newObject[el] !== newObject[name]
							? [...prev, newObject[el].valid]
							: prev,
					[]
				)
				.indexOf(false);

			return {
				...newObject,
				[name]: {
					...newObject[name],
					value,
					valid,
					touch: true
				},
				isValid: otherValid === -1 && valid
			};
		});
	};

	return [newObject, { setNew }];
};

export default useForm;
