import React, { Component } from "react";
import { connect } from "react-redux";
import { Link } from "react-router-dom";
import { bindActionCreators } from "redux";
import { Card, Icon, Avatar, Pagination } from "antd";

import * as actions from "../actions/category";

import jwtDecode from "../utils/checkExp";
import Loader from "../components/HOC/loader";
import WrapperComponent from "../components/HOC/resize";

class App extends Component {
	state = { current: 1, user: null, name: "", updateObject: null };

	componentDidMount() {
		const { getCategoryRequest } = this.props;

		getCategoryRequest({});

		const token = localStorage.getItem("token");

		jwtDecode(token);
	}

	onChange = page => {
		const { getCategoryRequest } = this.props;

		this.setState({ current: page });
		getCategoryRequest({ page });
	};

	submit = e => {
		e.preventDefault();
		const { create, update } = this.props;
		const { name, updateObject } = this.state;

		if (updateObject) {
			this.setState({ name: "", updateObject: null });
			return update({ id: updateObject.id, values: { name } });
		}

		this.setState({ name: "", updateObject: null });
		return create({ name });
	};

	onChange = e => {
		this.setState({ name: e.target.value });
	};

	onUpdate = updateObject => {
		this.setState({ updateObject, name: updateObject.name });
	};

	render() {
		const { category, isFetching, totalCount, deleteC } = this.props;
		const { current, user, name, updateObject } = this.state;
		return (
			<>
				<Loader flag={isFetching}>
					<div>Home</div>
					<form onSubmit={this.submit}>
						<label>
							New Category
							<input defaultValue={name} type="text" onChange={this.onChange} />
						</label>
						<button>{updateObject ? "Update" : "Create"}</button>
					</form>
					{/* {user && <img src={user.profilePhoto} alt="qwe" />} */}

					<div
						style={{
							display: "flex",
							flexFlow: "row wrap"
						}}>
						{category.length === 0 ? (
							<div>App doest have category</div>
						) : (
							category.map(el => (
								<div key={el._id}>
									<Card
										style={{ width: 200 }}
										cover={<img alt="example" src={el.photo} />}
										actions={[
											<Icon type="setting" />,
											<Icon type="edit" onClick={this.onUpdate.bind(null, { name: el.name, id: el._id })} />,
											<Icon type="delete" onClick={deleteC.bind(null, el._id)} />
										]}>
										<Card.Meta
											avatar={<Avatar src={user && user.profilePhoto} />}
											title={el.name}
											description="This is the description"
										/>
										<Link to={`/category/${el._id}`}>
											<h3>{el.name}</h3>
										</Link>
									</Card>
								</div>
							))
						)}
					</div>
				</Loader>
				{category.length !== 0 && (
					<Pagination current={current} onChange={this.onChange} defaultPageSize={5} total={totalCount} />
				)}
			</>
		);
	}
}

const mapStateToProps = state => {
	return {
		isFetching: state.category.isFetching,
		category: state.category.data,
		totalCount: state.category.totalCount,
		token: state.auth.token
	};
};

const mapDispatchToProps = dispatch => bindActionCreators({ ...actions }, dispatch);

export default connect(
	mapStateToProps,
	mapDispatchToProps
)(WrapperComponent(App));
